package de.hsbo.fbv.bmg.graphs;

import java.util.Arrays;

/**
 * Einfache Klassendeklaration fr ungerichtete und ungewichtete Kanten.<br>
 * Die Klasse speichert ein Objekt, auf das sich die Kante bezieht.
 * @author A. Zimmermann, HS Bochum 2011
 *
 */
public class Edge {
	
	// Attribute
	Object object = null;
	Node[] nodes = new Node[2];
	
	
	/**
	 * Konsturktor
	 * @param o
	 * @param n0
	 * @param n1
	 */
	public Edge(Object o, Node n0, Node n1) {
		object = o;
		nodes[0] = n0;
		nodes[1] = n1;		
	}

	/**
	 * Gibt die Knoten zurck.
	 * @return
	 */
	public Node[] getNodes() {
		return nodes;
	}
	
	/**
	 * Gibt das Bezugsobjekt zurck.
	 * @return
	 */
	public Object getObject() {
		return object;
	}
	
	/**
	 * Gibt an, ob die Kante am angegebenen Knoten angrenzt.
	 * (Knoten-Kanten-Inzidenz)
	 * @param n
	 * @return
	 */
	public boolean hasNode(Node n) {
		if(nodes[0]==n || nodes[1]==n)
			return true;
		else
			return false;
	}
	
	/**
	 * Gibt an, ob die Kante die angegebenen Knoten verbindet.
	 * (Knoten-Knoten-Adjazenz)
	 * @param n0
	 * @param n1
	 * @return
	 */
	public boolean hasNodes(Node n0, Node n1) {
		if((nodes[0]==n0 && nodes[1]==n1) ||
				(nodes[0]==n0 && nodes[1]==n0))
			return true;
		else
			return false;
	}
	
	/**
	 * Gibt den anderen Knoten der Kante an.
	 * @param n
	 * @return
	 */
	public Node getNextNode(Node n) {
		if(nodes[0]==n)
			return nodes[1];
		else if(nodes[1]==n)
			return nodes[0];
		else
			return null;
	}
	
	/**
	 * Gibt den gemeinsamen Knoten von zwei Kanten an.
	 * (Kanten-Kanten-Adjazenz)
	 * @param e
	 * @return
	 */
	public Node getCommonNode(Edge e) {
		if(e.hasNode(nodes[0]))
			return nodes[0];
		else if(e.hasNode(nodes[1]))
			return nodes[1];
		else
			return null;
	}
	

	@Override
	public String toString() {
		return "Edge [" + object + "]";
	}

}	// Ende Klassendeklaration
