package de.hsbo.fbv.bmg.graphs.buch;

import de.hsbo.fbv.bmg.graphs.DirectedEdge;
import de.hsbo.fbv.bmg.graphs.Edge;
import de.hsbo.fbv.bmg.graphs.Graph;
import de.hsbo.fbv.bmg.graphs.Node;

/**
 * Die Klasse zeigt den Aufbau des Graphen aus Abb. 2.20 (iii) und 
 * wertet die Inzidenzen bzw. Adjazenzen gem Tab. 2.6 aus. <br>
 * @author A.Zimmermann, HS Bochum 2011
 *
 */
public class DirectedGraphDemo {

	/**
	 * Hauptmethode
	 * @param args
	 */
	public static void main(String[] args) {
		// 1. Knoten erzeugen (gleiche Knoten wie bei ungerichtem Graph)
		Node v1 = new Node("v1");
		Node v2 = new Node("v2");
		Node v3 = new Node("v3");
		Node v4 = new Node("v4");
		Node v5 = new Node("v5");
		Node v6 = new Node("v6");
		Node v7 = new Node("v7");
		Node v8 = new Node("v8");
		
		// 2. Kanten erzeugen (anders als bei ungerichtetem Graph)
		DirectedEdge e1 = new DirectedEdge("e1", v1, v2);
		DirectedEdge e2 = new DirectedEdge("e2", v5, v2);
		DirectedEdge e3 = new DirectedEdge("e3", v4, v3);
		DirectedEdge e4 = new DirectedEdge("e4", v8, v6);
		DirectedEdge e5 = new DirectedEdge("e5", v5, v6);
		DirectedEdge e6 = new DirectedEdge("e6", v6, v3);
		DirectedEdge e7 = new DirectedEdge("e7", v7, v5);
		DirectedEdge e8 = new DirectedEdge("e8", v6, v5);
		
		// 3. Kanten in den Graph einfgen
		Graph graph = new Graph();
		graph.add(e1);
		graph.add(e2);		
		graph.add(e3);
		graph.add(e4);		
		graph.add(e5);		
		graph.add(e6);
		graph.add(e7);		
		graph.add(e8);		
		
		// Graph anzeigen
		System.out.println(graph);
		
		
		// Adjazenzen und Inzidenzen vorbereiten
		Edge[] edges = graph.getEdges();
		Node n = null;
		
		// Knoten-Adjazenz abfragen 
		System.out.println("\nKnoten-Adjazenzen:");
		for(int i=0; i<edges.length; i++)
			System.out.println(edges[i].getNodes()[0]+ " - " +edges[i].getNodes()[1]+" : "+edges[i]);
		
		// Knoten-Adjazenz abfragen 
		System.out.println("\nKanten-Adjazenzen:");
		for(int i=0; i<edges.length; i++)
			for(int j=0; j<edges.length; j++)
				if((n = edges[i].getCommonNode(edges[j]))!=null)
					System.out.println(edges[i]+ " - " +edges[j]+" : "+n);
		
		// Kanten-Knoten-Inzidenz abfragen
		System.out.println("\nKanten-Knoten-Inzidenzen:");
		for(int i=0; i<edges.length; i++) {
			System.out.println(edges[i]+ " - " +((DirectedEdge)edges[i]).getEndNode());
		}
		
		// Knoten-Kanten-Inzidenz abfragen
		System.out.println("\nKnoten-Kanten-Inzidenzen:");
		for(int i=0; i<edges.length; i++) {
			System.out.println(((DirectedEdge)edges[i]).getStartNode()+ " - " +edges[i]);
		}
		
	}

}
