package de.hsbo.fbv.bmg.graphs.buch;

import de.hsbo.fbv.bmg.graphs.Edge;
import de.hsbo.fbv.bmg.graphs.Graph;
import de.hsbo.fbv.bmg.graphs.Node;
import de.hsbo.fbv.bmg.graphs.WeightedEdge;

/**
 * Die Klasse zeigt den Aufbau des Graphen aus Abb. 2.20 (ii) und 
 * wertet die Inzidenzen bzw. Adjazenzen gem Tab. 2.6 aus. <br>
 * @author A.Zimmermann, HS Bochum 2011
 *
 */
public class WeightedGraphDemo {

	/**
	 * Hauptmethode
	 * @param args
	 */
	public static void main(String[] args) {
		// 1. Knoten erzeugen
		Node v1 = new Node("v1");
		Node v2 = new Node("v2");
		Node v3 = new Node("v3");
		Node v4 = new Node("v4");
		Node v5 = new Node("v5");
		Node v6 = new Node("v6");
		Node v7 = new Node("v7");
		Node v8 = new Node("v8");
		
		// 2. Kanten erzeugen
		Edge e1 = new WeightedEdge("e1", v1, v2, 1);
		Edge e2 = new WeightedEdge("e2", v2, v5, 2);
		Edge e3 = new WeightedEdge("e3", v3, v4, 1);
		Edge e4 = new WeightedEdge("e4", v6, v8, 2);
		Edge e5 = new WeightedEdge("e5", v5, v6, 4);
		Edge e6 = new WeightedEdge("e6", v3, v6, 1);
		Edge e7 = new WeightedEdge("e7", v5, v7, 1);
		
		// 3. Kanten in den Graph einfgen
		Graph graph = new Graph();
		graph.add(e1);
		graph.add(e2);		
		graph.add(e3);
		graph.add(e4);		
		graph.add(e5);		
		graph.add(e6);
		graph.add(e7);		
		
		// Graph anzeigen
		System.out.println(graph);
		
		
		// Adjazenzen und Inzidenzen vorbereiten
		Edge[] edges = graph.getEdges();
		Node n = null;
		
		// Knoten-Adjazenz abfragen 
		System.out.println("\nKnoten-Adjazenzen:");
		for(int i=0; i<edges.length; i++)
			System.out.println(edges[i].getNodes()[0]+ " - " +edges[i].getNodes()[1]+" : "+edges[i]);
		
		// Knoten-Adjazenz abfragen 
		System.out.println("\nKanten-Adjazenzen:");
		for(int i=0; i<edges.length; i++)
			for(int j=i+1; j<edges.length; j++)
				if((n = edges[i].getCommonNode(edges[j]))!=null)
					System.out.println(edges[i]+ " - " +edges[j]+" : "+n);
		
		// Kanten-Knoten-Inzidenz abfragen
		System.out.println("\nKanten-Knoten-Inzidenzen:");
		for(int i=0; i<edges.length; i++) {
			System.out.println(edges[i]+ " - " +edges[i].getNodes()[0]);
			System.out.println(edges[i]+ " - " +edges[i].getNodes()[1]);
		}
		
	}

}
